/* css Zen Garden submission 175 - 'Business Style', by Gunta Klavina, http://www.klavina.com/ */
/* css released under Creative Commons License - http://creativecommons.org/licenses/by-nc-sa/1.0/  */
/* All associated graphics copyright 2005, Gunta Klavina */
/* Added: July 9th, 2005 */

body {
    margin: 0;
    padding: 0;
    color: #333;
    font: 13px Trebuchet MS, Lucida Sans Unicode, Arial, sans-serif;
    background: #E2EBED;
    text-align: center;
}

a { color: #307082; }
a:hover { color: #D60808; }
abbr { border: none; }

.preamble h3, .summary h3, .explanation h3, .participation h3, .benefits h3, .requirements h3, .zen-resources h3.resources, .design-archives h3.archives {
    text-indent: 100%;
    white-space: nowrap;
    overflow: hidden;
}

.design-selection h3.select {
    display: none;
}

.page-wrapper {
    margin: 20 auto;
	padding: 80 0;
    width: 724px;
    position: relative;
    background: #fff;
    text-align: left;
}

header { position: absolute; top: 25px; left: 40px; }
h1 { font-size: 24px; margin: 0; }
h2 { font-size: 18px; margin: 0; }

.intro {
    font-size: 11px;
    margin: 20 auto;
    color: #505050;
    font: 12px/150% Trebuchet MS;
}

.preamble, .summary, .supporting { margin: 0 20px 0 243px; }
.supporting p, .preamble p, .summary p { line-height: 150%; margin: 10px 0 10px 0; }
.supporting h2, .preamble h2, .summary h2 { margin: 30px 0 10px 0; }

.cookies p { margin: 50px 20px 10px 20px; font: 8px Trebuchet MS; }
.userclass p { margin: 50px 20px 10px 20px; font: 8px Trebuchet MS; }
.sidebar { position: absolute; top: 200px; left: 0; width: 210px; font: 10px Trebuchet MS; }

.design-selection ul, .design-archives ul, .zen-resources ul {
    list-style-type: none;
    margin: 0;
    padding: 0 0 0 40px;
}

.design-selection ul li a {
    text-decoration: underline;
    display: block;
    font-size: 13px;
}

.design-selection ul li.c, .design-selection ul li a.designer-name {
    display: inline;
    font-size: 12px;
    color: #333;
}

.design-selection ul li a.designer-name { text-decoration: none; }
.design-selection ul li a.designer-name:hover { color: #D60808; }
.design-selection ul li { font-size: 12px; border-bottom: 1px solid #E6EEF0; }

footer {
    color: #909090;
    height: 48px;
    text-align: right;
    padding: 0 10px 0 0;
    line-height: 26px;
    font-size: 8px;
}

footer a { color: #909090; text-decoration: none; }
footer a:hover { text-decoration: underline; }
